@extends("layouts.dashboard.app")

@section("page-nav-title")
    <div class="app-title">
        <div>
            <h1><i class="fa fa-dashboard"></i>{{__('Items')}}</h1>
            <p>{{__('Create New Item')}}</p>
        </div>
        <ul class="app-breadcrumb breadcrumb">
            <li class="breadcrumb-item"><i class="fa fa-home fa-lg"></i></li>
            <li class="breadcrumb-item"><a href="{{route("items.index")}}">{{__('Items')}}</a></li>
            <li class="breadcrumb-item"><a href="#">{{__('Create')}}</a></li>
        </ul>
    </div>
@endsection
@section("content")
    <div class="row">
        <div class="col-lg-10 m-auto">
            <div class="tile">
                <h3 class="tile-title">{{__('Create New Item')}}</h3>
                <div class="tile-body">
                    <form method="post" action="{{route("items.store")}}" enctype="multipart/form-data">
                        @csrf
                        <div class="row">
                            <div class="col-lg-6">
                                <div class="form-group">
                                    <label class="control-label">{{__('English Item Name')}}</label>
                                    <input class="form-control @if($errors->has('item_name_en')) is-invalid @endif" type="text" name="item_name_en" placeholder="{{__('Enter English Item name')}}" value="{{inputValue("item_name_en")}}">
                                </div>
                                @error("item_name_en")
                                <div class="input-error">{{$message}}</div>
                                @enderror
                            </div>
                            <div class="col-lg-6">
                                <div class="form-group">
                                    <label class="control-label">{{__('Arabic Item Name')}}</label>
                                    <input class="form-control @if($errors->has('item_name_ar')) is-invalid @endif" type="text" name="item_name_ar" placeholder="{{__('Enter Arabic Item name')}}" value="{{inputValue("item_name_ar")}}">
                                </div>
                                @error("item_name_ar")
                                <div class="input-error">{{$message}}</div>
                                @enderror
                            </div>
                            <div class="col-lg-6">
                                <div class="form-group">
                                    <label for="exampleSelect1">{{__('Category')}}</label>
                                    <select class="form-control" id="exampleSelect1" name="category_id">
                                        <option value="">{{__('None')}}</option>
                                        @foreach($categories as $category)
                                            <option value="{{$category->id}}" {{selected("category_id", $category->id)}}>{{$category->category_name_en}} ( {{$category->category_name_ar}} )</option>
                                        @endforeach
                                    </select>
                                </div>
                                @error("category_id")
                                <div class="input-error">{{$message}}</div>
                                @enderror
                            </div>
                            <div class="col-lg-6 mt-4">
                                <div class="form-check-inline">
                                    <label class="form-check-label">
                                        <input type="radio"  onclick="myFunction(0)" checked class="form-check-input" name="optradio">Add Ons
                                    </label>
                                </div>
                                <div class="form-check-inline">
                                    <label class="form-check-label">
                                        <input type="radio" class="form-check-input"  onclick="myFunction(1)" name="optradio">Non Add Ons
                                    </label>
                                </div>
                            </div>
                            <div class="col-lg-6" id="item_price" >
                                <div class="form-group">
                                    <label class="control-label">{{__('Item Price')}}</label>
                                    <input class="form-control @if($errors->has('item_price')) is-invalid @endif" type="text" name="item_price" placeholder="{{__('Enter Item Price')}}" value="{{inputValue("item_price")}}">
                                </div>
                                @error("item_price")
                                <div class="input-error">{{$message}}</div>
                                @enderror
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-lg-6">
                                <div class="form-group">
                                    <label class="control-label">{{__('Arabic Item Description')}}</label>
                                    <textarea class="form-control @if($errors->has('item_description_ar')) is-invalid @endif" type="text" name="item_description_ar" style="height: 120px" placeholder="{{__('Enter Arabic Description')}}">{{inputValue("item_description_ar")}}</textarea>
                                </div>
                                @error("item_description_ar")
                                <div class="input-error">{{$message}}</div>
                                @enderror
                            </div>
                            <div class="col-lg-6">
                                <div class="form-group">
                                    <label class="control-label">{{__('English Item Description')}}</label>
                                    <textarea class="form-control @if($errors->has('item_description_en')) is-invalid @endif" type="text" name="item_description_en" style="height: 120px" placeholder="{{__('Enter English Description')}}" >{{inputValue("item_description_en")}}</textarea>
                                </div>
                                @error("item_description_en")
                                <div class="input-error">{{$message}}</div>
                                @enderror
                            </div>
                        </div>

                        <hr>

                        <div class="row">
                            <div class="col-lg-6">
                                <div class="form-group">
                                    <label class="control-label">{{__('Item Photo')}}</label>
                                    <div>
                                        <button class="btn btn-primary form-control button-upload-file" >
                                            <input class="input-file" type="file" name="item_image"  accept="image/x-png,image/gif,image/jpeg">
                                            <span class="upload-file-content">
                                                <i class="fas fa-upload fa-lg upload-file-content-icon left"></i>
                                                <span class="upload-file-content-text">{{__('Upload Photo')}}</span>
                                            </span>
                                        </button>
                                    </div>
                                </div>
                                @error("item_image")
                                <div class="input-error">{{$message}}</div>
                                @enderror
                            </div>
                                <div class="options-container" id="AddOns">
                                    <div hidden class="option-box" >
                                        <div hidden class="row">

                                        </div>
                                    </div>

                                    @if(isset($options_selected))
                                        @for($i=0; $i < $options_selected; $i++)
                                            <div class="option-box">
                                                <div class='text-right mt-3 mb-3'>
                                                    <span class='btn btn-primary remove-option'>Remove</span>
                                                </div>
                                                <div class="row">
                                                    <div class="col-lg-6">
                                                        <div class="form-group">
                                                            <label class="control-label">English Name</label>
                                                            <input class="form-control @if($errors->has('add_ons_list_en.' . $i)) is-invalid @endif" type="text" name="add_ons_list_en[]" placeholder="Enter English name" value="{{isset(old("add_ons_list_en")[$i]) ? old("add_ons_list_en")[$i] : null}}">
                                                        </div>
                                                        @error("add_ons_list_en." . $i)
                                                        <div class="input-error">{{$message}}</div>
                                                        @enderror
                                                    </div>
                                                    <div class="col-lg-6">
                                                        <div class="form-group">
                                                            <label class="control-label">Arabic Name</label>
                                                            <input class="form-control @if($errors->has('add_ons_list_en.' . $i)) is-invalid @endif" type="text" name="add_ons_list_ar[]" placeholder="Enter Arabic name" value="{{isset(old("add_ons_list_ar")[$i]) ? old("add_ons_list_ar")[$i] : null}}">
                                                        </div>
                                                        @error("add_ons_list_ar." . $i)
                                                        <div class="input-error">{{$message}}</div>
                                                        @enderror
                                                    </div>
                                                    <div class="col-lg-6">
                                                        <div class="form-group">
                                                            <label class="control-label">Adding Price</label>
                                                            <input class="form-control @if($errors->has('price.' . $i)) is-invalid @endif" type="text" name="price[]" placeholder="Enter Price" value="{{isset(old("price")[$i]) ? old("price")[$i] : null}}">
                                                        </div>
                                                        @error("price." . $i)
                                                        <div class="input-error">{{$message}}</div>
                                                        @enderror
                                                    </div>
                                                    <div class="col-lg-6">
                                                        <div class="form-group">
                                                            <label class="control-label">{{__('Discount Price')}}</label>
                                                            <input class="form-control @if($errors->has('Discount_price.' . $i)) is-invalid @endif" type="text" name="Discount_price[]" placeholder="{{__('Enter Price')}}" value="{{isset(old("Discount_price")[$i]) ? old("Discount_price")[$i] : null}}">
                                                        </div>
                                                        @error("Discount_price." . $i)
                                                        <div class="input-error">{{$message}}</div>
                                                        @enderror
                                                    </div>
                                                </div>
                                            </div>
                                        @endfor
                                    @endif
                                </div>
                                <div class="col-lg-12" >
                                    <span class="btn btn-primary add-option"><i class="fas fa-plus"></i>  Add Option</span>
                                </div>
                        </div>
                        <div class="tile-footer">
                            <button class="btn btn-primary" type="submit"><i class="fa fa-fw fa-lg fa-check-circle"></i>Create</button>
                        </div>
                    </form>
                </div>
            </div>
            @endsection
            @section("scripts")
                <script type="text/javascript">
                    if(document.location.hostname == 'pratikborsadiya.in') {
                        (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
                            (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
                            m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
                        })(window,document,'script','//www.google-analytics.com/analytics.js','ga');
                        ga('create', 'UA-72504830-1', 'auto');
                        ga('send', 'pageview');
                    }
                </script>

                <script type="text/javascript">
                    $(".add-option").on("click",function(){
                        let container = $(".options-container");
                        let row = $("<div class='row'></div>");
                        let box = $("<div class='option-box'></div>");


                        let group1 = $("<div class='form-group'></div>");
                        group1.append($("<label class='control-label'></label>").text("English name"));
                        group1.append($('<input class="form-control" type="text" name="add_ons_list_en[]" placeholder="Enter English name"">'));
                        row.append($("<div class='col-lg-6'></div>").append(group1));


                        let group2 = $("<div class='form-group'></div>");
                        group2.append($("<label class='control-label'></label>").text("Arabic name"));
                        group2.append($('<input class="form-control" type="text" name="add_ons_list_ar[]" placeholder="Enter Arabic name"">'));
                        row.append($("<div class='col-lg-6'></div>").append(group2));

                        let group3 = $("<div class='form-group'></div>");
                        group3.append($("<label class='control-label'></label>").text("Adding Price"));
                        group3.append($('<input class="form-control" type="text" name="price[]" placeholder="Enter Adding Price"">'));
                        row.append($("<div class='col-lg-6'></div>").append(group3));

                        let group4 = $("<div class='form-group'></div>");
                        group4.append($("<label class='control-label'></label>").text("Quantity"));
                        group4.append($('<input class="form-control" type="number" name="quantity[]" placeholder="Enter quantity"">'));
                        row.append($("<div class='col-lg-6'></div>").append(group4));


                        box.append($("<div class='text-right mt-3 mb-3'></div>").
                        append($("<span class='btn btn-primary remove-option'>Remove</span>")));
                        box.append(row);
                        container.append(box.append(box));
                        container.append($("hr"));
                    });

                    $(document).on("click",".remove-option",function (){
                        $(this).parents(".option-box").remove();
                    });
                </script>
                <script>
                    function myFunction(radio) {
                        if(radio){
                            $("#item_price").show(500);
                            $("#AddOns").hide(500);
                        }else{
                            $("#item_price").hide(500);
                            $("#AddOns").show(500);
                        }
                        $(".type").val(radio)
                    }
                </script>
@endsection
